@@ -78,13 +78,14 @@ argc_argv (char *instr, argv_t ** argv, char *commentstr)
 
   len = strlen (instr);
   pos = 0;
+  char quoted = 0;
 
   while (pos < len)
     {
+
       // printf ("%3d of %3d: %s\n", pos, len, instr);
-
+ 
       /* Comments are really, really special */
-
       if ((state == WHITESPACE) && (strchr (commentstr, *instr)))
 	{
 	  while ((*instr != '\n') && (*instr != '\0'))
@@ -105,11 +106,10 @@ argc_argv (char *instr, argv_t ** argv, char *commentstr)
 	    {
 	      quote = *instr;
 	      state = TOKENSTART;
+	      quoted = -1;
 	      if (*(instr + 1) == quote)
 		{		/* special case for NULL quote */
-		  quote = '\0';
 		  *instr = '\0';
-		  argv_array[arg_count].quoted = -1;
 		}
 	      else
 		{
@@ -119,11 +119,9 @@ argc_argv (char *instr, argv_t ** argv, char *commentstr)
 	    }
 	  else
 	    {			/* WORDSPACE, so quotes end or quotes within quotes */
-
 	      /* Is it the same kind of quote? */
-	      if (*instr == quote)
+	      if ( (*instr == quote) && quoted )
 		{
-		  argv_array[arg_count - 1].quoted = -1;
 		  quote = '\0';
 		  *instr = '\0';
 		  state = WHITESPACE;
@@ -189,14 +187,17 @@ argc_argv (char *instr, argv_t ** argv, char *commentstr)
 	      return (-1);
 	    }
 	  argv_array[arg_count - 1].string = instr;
-	  argv_array[arg_count].quoted = 0;
+	  argv_array[arg_count - 1].quoted = quoted;
 	  state = WORDSPACE;
+	  quoted = 0;
 	}
 
       instr++;
       pos++;
     }
 
+  if ( arg_count == 0 ) return (0);
+
   argv_array[arg_count].string = NULL;
   *argv = argv_array;
   return (arg_count);
@@ -337,14 +338,15 @@ main ()
 
 
   strcpy (string,
-	  "\\This\\ string will be  '' \"separated into\"  \"'\\\"'\" ' 15 ' elements.\n"
+	  "\\This\\ string will be  '' \"separated into\"  \"'\\\"'\" ' 16 ' elements.\n"
 	  "' including a multi-line\n"
 	  "element' with a comment.  # This should not be parsed\n"
 	  ";Nor should this\n" "The End.");
 
-  printf ("%s\n", string);
 
   argc = argc_argv (string, &argv, "#;");
+  printf ("%s\n", string);
+
   for (count = 0; count < argc; count++)
     {
       printf ("%03d: [%s] ", count, argv[count].string, "");
