@@ -692,7 +692,6 @@ main (int argc, char *argv[])
 #endif
   script_t *scriptchain;
 
-  int retval = 0;
   char *filename = NULL;
 
   argv_t *av = NULL;
@@ -878,8 +877,8 @@ main (int argc, char *argv[])
 	  if (strcasecmp (getenv ("REQUEST_METHOD"), "POST") == 0)
 	    {
 	      if (global.acceptall == TRUE)
-		retval = ReadCGIQueryString (env);
-	      retval = ReadCGIPOSTValues (env);
+		ReadCGIQueryString (env);
+	      ReadCGIPOSTValues (env);
 	    }
 	}
     }
